@@ -11,18 +11,18 @@ from autoarray.inversion.mappers import mapper as Mapper
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerNUFFT
 from autoarray.operators.transformer import TransformerNUFFT
-from autoarray.structures.arrays import Array, Values
+from autoarray.structures.arrays import Array2D, ValuesIrregular
 from autoarray.structures.grids import (
-    Grid,
-    GridIterate,
-    GridInterpolate,
-    GridIrregular,
-    GridIrregularGrouped,
-    GridRectangular,
-    GridVoronoi,
+    Grid2D,
+    Grid2DIterate,
+    Grid2DInterpolate,
+    Grid2DIrregular,
+    Grid2DIrregular,
+    Grid2DRectangular,
+    Grid2DVoronoi,
 )
-from autoarray import VectorFieldIrregular
-from autoarray.structures.kernel import Kernel
+from autoarray import VectorField2DIrregular
+from autoarray.structures.kernel import Kernel2D
 from autoarray.structures.visibilities import Visibilities, VisibilitiesNoiseMap
 from autogalaxy import util
 from autogalaxy.dataset.imaging import SettingsMaskedImaging
@@ -37,6 +37,7 @@ from autogalaxy.pipeline.phase.extensions.hyper_phase import HyperPhase
 from autogalaxy.pipeline.pipeline import PipelineDataset
 from autogalaxy.plane.plane import Plane
 from autogalaxy.profiles import (
+    point_sources as ps,
     light_profiles as lp,
     mass_profiles as mp,
     light_and_mass_profiles as lmp,
@@ -48,10 +49,14 @@ from . import plot
 from .dataset.imaging import MaskedImaging, SimulatorImaging
 from .dataset.interferometer import MaskedInterferometer, SimulatorInterferometer
 from .fit.fit import FitImaging, FitInterferometer
-from .fit.fit_positions import FitPositionsSourcePlaneMaxSeparation
+from .fit.fit_point_source import (
+    FitPositionsSourceMaxSeparation,
+    FitPositionsImage,
+    FitFluxes,
+)
 from .lens.settings import SettingsLens
 from .lens.ray_tracing import Tracer
-from .lens.positions_solver import PositionsFinder
+from .lens.positions_solver import PositionsSolver
 from .pipeline.setup import (
     SetupPipeline,
     SetupHyper,
@@ -70,8 +75,10 @@ from .pipeline.slam import (
 )
 from .pipeline.phase.settings import SettingsPhaseImaging
 from .pipeline.phase.settings import SettingsPhaseInterferometer
+from .pipeline.phase.settings import SettingsPhasePositions
 from .pipeline.phase.imaging.phase import PhaseImaging
 from .pipeline.phase.interferometer.phase import PhaseInterferometer
+from .pipeline.phase.point_source.phase import PhasePointSource
 from .pipeline.phase.extensions.stochastic_phase import StochasticPhase
 from .pipeline.phase.phase_galaxy import PhaseGalaxy
 
@@ -79,4 +86,4 @@ from autoconf import conf
 
 conf.instance.register(__file__)
 
-__version__ = '1.9.2'
+__version__ = '1.12.1'
