@@ -136,6 +136,27 @@ class FitImaging(aa_fit.FitImaging):
 
         return model_images_of_planes
 
+    @property
+    def subtracted_images_of_planes(self):
+
+        subtracted_images_of_planes = []
+
+        model_images_of_planes = self.model_images_of_planes
+
+        for galaxy_index in range(len(self.tracer.planes)):
+
+            other_planes_model_images = [
+                model_image
+                for i, model_image in enumerate(model_images_of_planes)
+                if i != galaxy_index
+            ]
+
+            subtracted_image = self.image - sum(other_planes_model_images)
+
+            subtracted_images_of_planes.append(subtracted_image)
+
+        return subtracted_images_of_planes
+
     @property
     def unmasked_blurred_image(self):
         return self.tracer.unmasked_blurred_image_from_grid_and_psf(
@@ -251,8 +272,8 @@ class FitInterferometer(aa_fit.FitInterferometer):
         )
 
         for path, image in galaxy_model_image_dict.items():
-            if hasattr(image, "in_1d_binned"):
-                galaxy_model_image_dict[path] = image.in_1d_binned
+            if hasattr(image, "slim_binned"):
+                galaxy_model_image_dict[path] = image.slim_binned
 
         # TODO : Extend to multiple inversioons across Planes
 
