@@ -5,7 +5,7 @@ from os import path
 from astropy import cosmology as cosmo
 from autoarray.inversion import pixelizations as pix
 from autoarray.inversion import inversions as inv
-from autoarray.structures import grids
+from autoarray.structures import arrays, grids
 from autogalaxy import lensing
 from autogalaxy.galaxy import galaxy as g
 from autogalaxy.plane import plane as pl
@@ -91,6 +91,28 @@ class AbstractTracer(lensing.LensingObject, ABC):
             ]
         )
 
+    @property
+    def point_source_dict(self):
+
+        point_source_dict = {}
+
+        for plane in self.planes:
+            for key, value in plane.point_source_dict.items():
+                point_source_dict[key] = value
+
+        return point_source_dict
+
+    @property
+    def point_source_plane_index_dict(self):
+
+        point_source_dict = {}
+
+        for index, plane in enumerate(self.planes):
+            for key, value in plane.point_source_dict.items():
+                point_source_dict[key] = index
+
+        return point_source_dict
+
     @property
     def planes_with_light_profile(self):
         return list(filter(lambda plane: plane.has_light_profile, self.planes))
@@ -99,29 +121,151 @@ class AbstractTracer(lensing.LensingObject, ABC):
     def planes_with_mass_profile(self):
         return list(filter(lambda plane: plane.has_mass_profile, self.planes))
 
-    @property
-    def light_profile_centres(self):
+    def extract_attribute(self, cls, name):
         """
-        Returns the light profile centres of the tracer as a `GridIrregularGrouped` object, which structures the centres
-            in lists according to which plane they come from.
+        Returns an attribute of a class in the tracer as a `ValueIrregular` or `Grid2DIrregular` object.
 
-            Fo example, if the tracer has two planes, the first with one light profile and second with two light profiles
-            this returns:
+        For example, if a tracer has an image-plane with a galaxy with two light profiles, the following:
 
-            [[(y0, x0)], [(y0, x0), (y1, x1)]]
+        `tracer.extract_attribute(cls=LightProfile, name="axis_ratio")`
 
-            This is used for visualization, for example plotting the centres of all light profiles colored by their galaxy.
+        would return:
 
-            The centres of light-sheets are filtered out, as their centres are not relevant to lensing calculations
+        ValuesIrregular(values=[axis_ratio_0, axis_ratio_1])
 
+        If the image plane has has two galaxies with two mass profiles and the source plane another galaxy with a
+        mass profile, the following:
+
+        `tracer.extract_attribute(cls=MassProfile, name="centres")`
+
+        would return:
+
+        GridIrregular2D(grid=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1), (centre_y_2, centre_x_2)])
+
+        This is used for visualization, for example plotting the centres of all mass profiles colored by their profile.
         """
-        return grids.GridIrregularGrouped(
-            [
-                list(plane.light_profile_centres)
+
+        def extract(value, name):
+
+            try:
+                return getattr(value, name)
+            except (AttributeError, IndexError):
+                return None
+
+        attributes = [
+            extract(value, name)
+            for galaxy in self.galaxies
+            for value in galaxy.__dict__.values()
+            if isinstance(value, cls)
+        ]
+
+        if attributes == []:
+            return None
+        elif isinstance(attributes[0], float):
+            return arrays.ValuesIrregular(values=attributes)
+        elif isinstance(attributes[0], tuple):
+            return grids.Grid2DIrregular(grid=attributes)
+
+    def extract_attributes_of_planes(self, cls, name, filter_nones=False):
+        """
+        Returns an attribute of a class in the tracer as a list of `ValueIrregular` or `Grid2DIrregular` objects, where
+        the indexes of the list correspond to the tracer's planes.
+
+        For example, if a tracer has an image-plane with a galaxy with a light profile and a source-plane with a galaxy
+        with a light profile, the following:
+
+        `tracer.extract_attributes_of_planes(cls=LightProfile, name="axis_ratio")`
+
+        would return:
+
+        [ValuesIrregular(values=[axis_ratio_0]), ValuesIrregular(values=[axis_ratio_1])]
+
+        If the image plane has two galaxies with a mass profile each and the source plane another galaxy with a
+        mass profile, the following:
+
+        `tracer.extract_attributes_of_planes(cls=MassProfile, name="centres")`
+
+        would return:
+
+        [
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)]),
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1)])
+        ]
+
+        If a Profile does not have a certain entry, it is replaced with a None, although the nones can be removed
+        by setting `filter_nones=True`.
+
+        This is used for visualization, for example plotting the centres of all mass profiles colored by their profile.
+        """
+        if filter_nones:
+
+            return [
+                plane.extract_attribute(cls=cls, name=name)
                 for plane in self.planes
-                if plane.has_light_profile
+                if plane.extract_attribute(cls=cls, name=name) is not None
+            ]
+
+        else:
+
+            return [
+                plane.extract_attribute(cls=cls, name=name) for plane in self.planes
+            ]
+
+    def extract_attributes_of_galaxies(self, cls, name, filter_nones=False):
+        """
+        Returns an attribute of a class in the tracer as a list of `ValueIrregular` or `Grid2DIrregular` objects, where
+        the indexes of the list correspond to the tracer's galaxies. If a plane has multiple galaxies they are split
+        into separate indexes int he list.
+
+        For example, if a tracer has an image-plane with a galaxy with a light profile and a source-plane with a galaxy
+        with a light profile, the following:
+
+        `tracer.extract_attributes_of_galaxies(cls=LightProfile, name="axis_ratio")`
+
+        would return:
+
+        [ValuesIrregular(values=[axis_ratio_0]), ValuesIrregular(values=[axis_ratio_1])]
+
+        If the image plane has two galaxies with a mass profile each and the source plane another galaxy with a
+        mass profile, the following:
+
+        `tracer.extract_attributes_of_galaxies(cls=MassProfile, name="centres")`
+
+        would return:
+
+        [
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)]),
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)])
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)])
+        ]
+
+        If the first galaxy in the image plane in the example above had two mass profiles as well as the galaxy in the
+        source plane it would return:
+
+                [
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0), (centre_y_1, centre_x_1)]),
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0)])
+            Grid2DIrregular(grid=[(centre_y_0, centre_x_0, (centre_y_1, centre_x_1))])
+        ]
+
+        If a Profile does not have a certain entry, it is replaced with a None, although the nones can be removed
+        by setting `filter_nones=True`.
+
+        This is used for visualization, for example plotting the centres of all mass profiles colored by their profile.
+        """
+        if filter_nones:
+
+            return [
+                galaxy.extract_attribute(cls=cls, name=name)
+                for galaxy in self.galaxies
+                if galaxy.extract_attribute(cls=cls, name=name) is not None
+            ]
+
+        else:
+
+            return [
+                galaxy.extract_attribute(cls=cls, name=name) for galaxy in self.galaxies
             ]
-        )
 
     @property
     def mass_profiles(self):
@@ -135,30 +279,6 @@ class AbstractTracer(lensing.LensingObject, ABC):
     def mass_profiles_of_planes(self):
         return [plane.mass_profiles for plane in self.planes if plane.has_mass_profile]
 
-    @property
-    def mass_profile_centres(self):
-        """
-        Returns the mass profile centres of the tracer as a `GridIrregularGrouped` object, which structures the centres
-            in lists according to which plane they come from.
-
-            Fo example, if the tracer has two planes, the first with one mass profile and second with two mass profiles
-            this returns:
-
-            [[(y0, x0)], [(y0, x0), (y1, x1)]]
-
-            This is used for visualization, for example plotting the centres of all mass profiles colored by their galaxy.
-
-            The centres of mass-sheets are filtered out, as their centres are not relevant to lensing calculations
-
-        """
-        return grids.GridIrregularGrouped(
-            [
-                list(plane.mass_profile_centres)
-                for plane in self.planes
-                if plane.has_mass_profile
-            ]
-        )
-
     @property
     def plane_indexes_with_pixelizations(self):
         plane_indexes_with_inversions = [
@@ -226,7 +346,7 @@ class AbstractTracerLensing(AbstractTracer, ABC):
                         scaling_factor * traced_deflections[previous_plane_index]
                     )
 
-                    # TODO : Setup as GridInterpolate
+                    # TODO : Setup as Grid2DInterpolate
 
                     scaled_grid -= scaled_deflections
 
@@ -275,7 +395,9 @@ class AbstractTracerLensing(AbstractTracer, ABC):
 
     def padded_image_from_grid_and_psf_shape(self, grid, psf_shape_2d):
 
-        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf_shape_2d)
+        padded_grid = grid.padded_grid_from_kernel_shape(
+            kernel_shape_native=psf_shape_2d
+        )
 
         return self.image_from_grid(grid=padded_grid)
 
@@ -305,7 +427,7 @@ class AbstractTracerLensing(AbstractTracer, ABC):
 
         Parameters
         ----------
-        grid : ndsrray or aa.Grid
+        grid : ndsrray or aa.Grid2D
             The image-plane grid which is traced to the redshift.
         redshift : float
             The redshift the image-plane grid is traced to.
@@ -381,14 +503,14 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         """
 
         if not self.has_light_profile:
-            return np.zeros(shape=grid.shape_1d)
+            return np.zeros(shape=grid.shape_slim)
 
         image = self.image_from_grid(grid=grid)
 
         blurring_image = self.image_from_grid(grid=blurring_grid)
 
         return psf.convolved_array_from_array_2d_and_mask(
-            array_2d=image.in_2d_binned + blurring_image.in_2d_binned, mask=grid.mask
+            array_2d=image.native_binned + blurring_image.native_binned, mask=grid.mask
         )
 
     def blurred_images_of_planes_from_grid_and_psf(self, grid, psf, blurring_grid):
@@ -429,7 +551,7 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
         """
 
         if not self.has_light_profile:
-            return np.zeros(shape=grid.shape_1d)
+            return np.zeros(shape=grid.shape_slim)
 
         image = self.image_from_grid(grid=grid)
 
@@ -469,7 +591,9 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
 
     def unmasked_blurred_image_from_grid_and_psf(self, grid, psf):
 
-        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf.shape_2d)
+        padded_grid = grid.padded_grid_from_kernel_shape(
+            kernel_shape_native=psf.shape_native
+        )
 
         padded_image = self.image_from_grid(grid=padded_grid)
 
@@ -479,7 +603,9 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
 
     def unmasked_blurred_image_of_planes_from_grid_and_psf(self, grid, psf):
 
-        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf.shape_2d)
+        padded_grid = grid.padded_grid_from_kernel_shape(
+            kernel_shape_native=psf.shape_native
+        )
 
         traced_padded_grids = self.traced_grids_of_planes_from_grid(grid=padded_grid)
 
@@ -502,7 +628,9 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
 
         unmasked_blurred_images_of_planes_and_galaxies = []
 
-        padded_grid = grid.padded_grid_from_kernel_shape(kernel_shape_2d=psf.shape_2d)
+        padded_grid = grid.padded_grid_from_kernel_shape(
+            kernel_shape_native=psf.shape_native
+        )
 
         traced_padded_grids = self.traced_grids_of_planes_from_grid(grid=padded_grid)
 
@@ -592,7 +720,10 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
                 )
                 traced_sparse_grids_of_planes.append(traced_sparse_grids[plane_index])
 
-        return traced_sparse_grids_of_planes
+        if len(sparse_image_plane_grids_of_planes) > 1:
+            return traced_sparse_grids_of_planes, sparse_image_plane_grids_of_planes[1]
+        else:
+            return traced_sparse_grids_of_planes, sparse_image_plane_grids_of_planes[0]
 
     def mappers_of_planes_from_grid(
         self, grid, settings_pixelization=pix.SettingsPixelization()
@@ -602,7 +733,7 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
 
         traced_grids_of_planes = self.traced_grids_of_planes_from_grid(grid=grid)
 
-        traced_sparse_grids_of_planes = self.traced_sparse_grids_of_planes_from_grid(
+        traced_sparse_grids_of_planes, sparse_image_plane_grid = self.traced_sparse_grids_of_planes_from_grid(
             grid=grid, settings_pixelization=settings_pixelization
         )
 
@@ -614,6 +745,7 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
                 mapper = plane.mapper_from_grid_and_sparse_grid(
                     grid=traced_grids_of_planes[plane_index],
                     sparse_grid=traced_sparse_grids_of_planes[plane_index],
+                    sparse_image_plane_grid=sparse_image_plane_grid,
                     settings_pixelization=settings_pixelization,
                 )
                 mappers_of_planes.append(mapper)
@@ -744,6 +876,11 @@ class AbstractTracerData(AbstractTracerLensing, ABC):
 
 
 class Tracer(AbstractTracerData):
+    @property
+    def flux_hack(self):
+        """This is a placeholder to get flux modeling working for Nan Li before I do this proeprly. with dictionaries."""
+        return self.planes[1].galaxies[0].light_profiles[0].flux
+
     @classmethod
     def from_galaxies(cls, galaxies, cosmology=cosmo.Planck15):
 
