@@ -6,8 +6,9 @@ from autofit.exc import FitException
 from autogalaxy.galaxy import galaxy as g
 from autogalaxy.pipeline.phase.dataset import analysis as ag_analysis
 from autogalaxy.pipeline.phase.interferometer.analysis import Attributes as AgAttributes
+from autogalaxy.plot.mat_wrap import lensing_visuals, lensing_include
 from autolens.fit import fit
-from autolens.pipeline import visualizer
+from autolens.pipeline import visualizer as vis
 from autolens.pipeline.phase.dataset import analysis as analysis_dataset
 
 
@@ -21,10 +22,6 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             results=results,
         )
 
-        self.visualizer = visualizer.PhaseInterferometerVisualizer(
-            masked_dataset=masked_interferometer
-        )
-
         result = ag_analysis.last_result_with_use_as_hyper_dataset(results=results)
 
         if result is not None:
@@ -182,8 +179,6 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
 
     def visualize(self, paths: af.Paths, instance, during_analysis):
 
-        self.visualizer.visualize_interferometer(paths=paths)
-
         self.associate_hyper_images(instance=instance)
         tracer = self.tracer_for_instance(instance=instance)
 
@@ -195,52 +190,36 @@ class Analysis(ag_analysis.Analysis, analysis_dataset.Analysis):
             tracer=tracer, hyper_background_noise=hyper_background_noise
         )
 
-        if tracer.has_mass_profile:
-
-            try:
-
-                visualizer = self.visualizer.new_visualizer_with_preloaded_critical_curves_and_caustics(
-                    preloaded_critical_curves=tracer.critical_curves,
-                    preloaded_caustics=tracer.caustics,
-                )
-
-            except (Exception, IndexError, ValueError):
-
-                visualizer = self.visualizer
-
-        else:
-
-            visualizer = self.visualizer
-
-        visualizer.visualize_ray_tracing(
-            paths=paths, tracer=fit.tracer, during_analysis=during_analysis
+        visualizer = vis.Visualizer(visualize_path=paths.image_path)
+        visualizer.visualize_interferometer(
+            interferometer=self.masked_interferometer.interferometer
         )
-        visualizer.visualize_fit(paths=paths, fit=fit, during_analysis=during_analysis)
-
-        self.visualizer.visualize_hyper_images(
-            paths=paths,
-            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
-            hyper_model_image=self.hyper_model_image,
-            contribution_maps_of_galaxies=tracer.contribution_maps_of_planes,
+        visualizer.visualize_fit_interferometer(
+            fit=fit, during_analysis=during_analysis
         )
-
-        if self.visualizer.plot_fit_no_hyper:
-
-            fit = self.masked_interferometer_fit_for_tracer(
-                tracer=tracer,
-                hyper_background_noise=hyper_background_noise,
-                use_hyper_scalings=False,
+        visualizer.visualize_tracer(
+            tracer=fit.tracer, grid=fit.grid, during_analysis=during_analysis
+        )
+        if fit.inversion is not None:
+            visualizer.visualize_inversion(
+                inversion=fit.inversion, during_analysis=during_analysis
             )
 
-            try:
-                visualizer.visualize_fit(
-                    paths=paths,
-                    fit=fit,
-                    during_analysis=during_analysis,
-                    subfolders="fit_no_hyper",
-                )
-            except Exception:
-                pass
+        visualizer.visualize_hyper_images(
+            hyper_galaxy_image_path_dict=self.hyper_galaxy_image_path_dict,
+            hyper_model_image=self.hyper_model_image,
+            tracer=tracer,
+        )
+
+        if visualizer.plot_fit_no_hyper:
+
+            fit = self.masked_interferometer_fit_for_tracer(
+                tracer=tracer, hyper_background_noise=None, use_hyper_scalings=False
+            )
+
+            visualizer.visualize_fit_interferometer(
+                fit=fit, during_analysis=during_analysis, subfolders="fit_no_hyper"
+            )
 
     def make_attributes(self):
         return Attributes(
