@@ -1,5 +1,6 @@
 import autofit as af
 from autoconf import conf
+from autoarray.structures import grids
 from autogalaxy.pipeline import setup
 from autoarray.inversion import pixelizations as pix, regularization as reg
 from autogalaxy.profiles import (
@@ -219,31 +220,17 @@ class SetupHyper(setup.SetupHyper):
         if not self.hyper_galaxies_lens:
             return None
 
-        if result.hyper.model.galaxies.lens.hyper_galaxy is None:
-            return None
-
-        hyper_galaxy = af.PriorModel(g.HyperGalaxy)
-
-        if noise_factor_is_model:
-
-            hyper_galaxy.noise_factor = (
-                result.hyper.model.galaxies.lens.hyper_galaxy.noise_factor
+        if hasattr(result, "hyper"):
+            return self.hyper_galaxy_from_galaxy_model_and_instance(
+                galaxy_model=result.hyper.model.galaxies.lens,
+                galaxy_instance=result.hyper.instance.galaxies.lens,
+                noise_factor_is_model=noise_factor_is_model,
             )
 
-        else:
-
-            hyper_galaxy.noise_factor = (
-                result.hyper.instance.galaxies.lens.hyper_galaxy.noise_factor
-            )
-
-        hyper_galaxy.contribution_factor = (
-            result.hyper.instance.galaxies.lens.hyper_galaxy.contribution_factor
+        return self.hyper_galaxy_from_galaxy_model_and_instance(
+            galaxy_model=result.model.galaxies.lens,
+            galaxy_instance=result.instance.galaxies.lens,
         )
-        hyper_galaxy.noise_power = (
-            result.hyper.instance.galaxies.lens.hyper_galaxy.noise_power
-        )
-
-        return hyper_galaxy
 
     def hyper_galaxy_source_from_result(
         self, result: af.Result, noise_factor_is_model=False
@@ -277,29 +264,35 @@ class SetupHyper(setup.SetupHyper):
         if not self.hyper_galaxies_source:
             return None
 
-        if result.hyper.model.galaxies.source.hyper_galaxy is None:
-            return None
+        if hasattr(result, "hyper"):
+            return self.hyper_galaxy_from_galaxy_model_and_instance(
+                galaxy_model=result.hyper.model.galaxies.source,
+                galaxy_instance=result.hyper.instance.galaxies.source,
+                noise_factor_is_model=noise_factor_is_model,
+            )
+
+        return self.hyper_galaxy_from_galaxy_model_and_instance(
+            galaxy_model=result.model.galaxies.source,
+            galaxy_instance=result.instance.galaxies.source,
+        )
+
+    def hyper_galaxy_from_galaxy_model_and_instance(
+        self, galaxy_model, galaxy_instance, noise_factor_is_model=False
+    ):
 
         hyper_galaxy = af.PriorModel(g.HyperGalaxy)
 
-        if noise_factor_is_model:
+        if galaxy_model.hyper_galaxy is None:
+            return None
 
-            hyper_galaxy.noise_factor = (
-                result.hyper.model.galaxies.source.hyper_galaxy.noise_factor
-            )
+        if not noise_factor_is_model:
 
-        else:
-
-            hyper_galaxy.noise_factor = (
-                result.hyper.instance.galaxies.source.hyper_galaxy.noise_factor
-            )
+            hyper_galaxy.noise_factor = galaxy_instance.hyper_galaxy.noise_factor
 
         hyper_galaxy.contribution_factor = (
-            result.hyper.instance.galaxies.source.hyper_galaxy.contribution_factor
-        )
-        hyper_galaxy.noise_power = (
-            result.hyper.instance.galaxies.source.hyper_galaxy.noise_power
+            galaxy_instance.hyper_galaxy.contribution_factor
         )
+        hyper_galaxy.noise_power = galaxy_instance.hyper_galaxy.noise_power
 
         return hyper_galaxy
 
@@ -401,6 +394,7 @@ class SetupMassLightDark(setup.SetupMassLightDark, AbstractSetupMass):
             lmp.LightMassProfile
         ) = lmp.EllipticalExponential,
         envelope_prior_model: af.PriorModel(lmp.LightMassProfile) = None,
+        dark_prior_model: af.PriorModel(mp.MassProfile) = mp.EllipticalNFWMCRLudlow,
         mass_centre: (float, float) = None,
         constant_mass_to_light_ratio: bool = False,
         align_bulge_dark_centre: bool = False,
@@ -440,6 +434,7 @@ class SetupMassLightDark(setup.SetupMassLightDark, AbstractSetupMass):
             bulge_prior_model=bulge_prior_model,
             disk_prior_model=disk_prior_model,
             envelope_prior_model=envelope_prior_model,
+            dark_prior_model=dark_prior_model,
             mass_centre=mass_centre,
             constant_mass_to_light_ratio=constant_mass_to_light_ratio,
             align_bulge_dark_centre=align_bulge_dark_centre,
