@@ -8,7 +8,7 @@ from autolens.pipeline import setup
 
 from typing import Union
 
-import copy
+import os
 
 
 class AbstractSLaMPipeline:
@@ -233,11 +233,11 @@ class SLaMPipelineMass(AbstractSLaMPipeline):
             return f"__{conf.instance['notation']['setup_tags']['pipeline']['light_is_model']}"
         return f"__{conf.instance['notation']['setup_tags']['pipeline']['light_is_instance']}"
 
-    def smbh_prior_model_from_results(self, results: af.ResultsCollection):
+    def smbh_prior_model_from_result(self, result: af.Result):
 
         if self.setup_smbh is not None:
             return self.setup_smbh.smbh_from_centre(
-                centre=results.last.instance.galaxies.lens.sersic.centre
+                centre=result.instance.galaxies.lens.bulge.centre
             )
 
     def shear_from_result(self, result: af.Result, as_instance=False):
@@ -351,6 +351,19 @@ class SLaM:
 
         self.setup_subhalo = setup_subhalo
 
+    def path_prefix_from(self, *folder_names: [str]):
+
+        folder_names_new = []
+
+        for folder_name in folder_names:
+            if len(folder_name) < 255:
+                folder_names_new.append(folder_name)
+            else:
+                folder_names_new.append(folder_name[: len(folder_name) // 2])
+                folder_names_new.append(folder_name[len(folder_name) // 2 :])
+
+        return os.path.join(*folder_names_new)
+
     @property
     def source_parametric_tag(self) -> str:
         """Generate the pipeline's overall tag, which customizes the 'setup' folder the results are output to."""
@@ -475,16 +488,23 @@ class SLaM:
             )
         else:
             light_tag = ""
+
         mass_tag = (
             f"__{self.pipeline_mass.setup_mass.tag}"
             if self.pipeline_mass.setup_mass is not None
             else ""
         )
 
-        return f"{setup_tag}{hyper_tag}{light_tag}{mass_tag}{source_tag}"
+        smbh_tag = (
+            f"__{self.pipeline_mass.setup_smbh.tag}"
+            if self.pipeline_mass.setup_smbh is not None
+            else ""
+        )
 
-    def lens_for_mass_pipeline_from_results(
-        self, results: af.ResultsCollection, mass: af.PriorModel, shear: af.PriorModel
+        return f"{setup_tag}{hyper_tag}{light_tag}{mass_tag}{smbh_tag}{source_tag}"
+
+    def lens_for_mass_pipeline_from_result(
+        self, result: af.Result, mass: af.PriorModel, shear: af.PriorModel
     ) -> ag.GalaxyModel:
         """Setup the lens model for a `Mass` pipeline using the previous `Light` pipeline and phase results.
 
@@ -513,13 +533,13 @@ class SLaM:
 
             return ag.GalaxyModel(
                 redshift=self.redshift_lens,
-                bulge=results.last.instance.galaxies.lens.bulge,
-                disk=results.last.instance.galaxies.lens.disk,
-                envelope=results.last.instance.galaxies.lens.envelope,
+                bulge=result.instance.galaxies.lens.bulge,
+                disk=result.instance.galaxies.lens.disk,
+                envelope=result.instance.galaxies.lens.envelope,
                 mass=mass,
                 shear=shear,
                 hyper_galaxy=self.setup_hyper.hyper_galaxy_lens_from_result(
-                    result=results.last
+                    result=result
                 ),
             )
 
@@ -527,18 +547,18 @@ class SLaM:
 
             return ag.GalaxyModel(
                 redshift=self.redshift_lens,
-                bulge=results.last.model.galaxies.lens.bulge,
-                disk=results.last.model.galaxies.lens.disk,
-                envelope=results.last.model.galaxies.lens.envelope,
+                bulge=result.model.galaxies.lens.bulge,
+                disk=result.model.galaxies.lens.disk,
+                envelope=result.model.galaxies.lens.envelope,
                 mass=mass,
                 shear=shear,
                 hyper_galaxy=self.setup_hyper.hyper_galaxy_lens_from_result(
-                    result=results.last
+                    result=result
                 ),
             )
 
-    def lens_for_subhalo_pipeline_from_results(
-        self, results: af.ResultsCollection
+    def lens_for_subhalo_pipeline_from_result(
+        self, result: af.Result
     ) -> ag.GalaxyModel:
         """
         Pass the lens `PriorModel` as a `model` or `instance` from the `MassPipeline` to the `SubhaloPipeline`.
@@ -558,10 +578,10 @@ class SLaM:
 
             return ag.GalaxyModel(
                 redshift=self.redshift_lens,
-                mass=results.last.model.galaxies.lens.mass,
-                shear=results.last.model.galaxies.lens.shear,
+                mass=result.model.galaxies.lens.mass,
+                shear=result.model.galaxies.lens.shear,
                 hyper_galaxy=self.setup_hyper.hyper_galaxy_lens_from_result(
-                    result=results.last
+                    result=result
                 ),
             )
 
@@ -569,15 +589,15 @@ class SLaM:
 
             return ag.GalaxyModel(
                 redshift=self.redshift_lens,
-                mass=results.last.instance.galaxies.lens.mass,
-                shear=results.last.instance.galaxies.lens.shear,
+                mass=result.instance.galaxies.lens.mass,
+                shear=result.instance.galaxies.lens.shear,
                 hyper_galaxy=self.setup_hyper.hyper_galaxy_lens_from_result(
-                    result=results.last
+                    result=result
                 ),
             )
 
-    def _source_parametric_from_results(
-        self, results: af.ResultsCollection, source_is_model: bool = True
+    def _source_parametric_from_result(
+        self, result: af.Result, source_is_model: bool = True
     ) -> ag.GalaxyModel:
         """
          Pass a parametric source `PriorModel` as a `model` or `instance` from a previous pipeline.
@@ -595,17 +615,15 @@ class SLaM:
         ag.GalaxyModel
             Contains the `PriorModel`'s of the source's bulge, disk, etc.
         """
-        hyper_galaxy = self.setup_hyper.hyper_galaxy_source_from_result(
-            result=results.last
-        )
+        hyper_galaxy = self.setup_hyper.hyper_galaxy_source_from_result(result=result)
 
         if source_is_model:
 
             return ag.GalaxyModel(
                 redshift=self.redshift_source,
-                bulge=results.last.model.galaxies.source.bulge,
-                disk=results.last.model.galaxies.source.disk,
-                envelope=results.last.model.galaxies.source.envelope,
+                bulge=result.model.galaxies.source.bulge,
+                disk=result.model.galaxies.source.disk,
+                envelope=result.model.galaxies.source.envelope,
                 hyper_galaxy=hyper_galaxy,
             )
 
@@ -613,14 +631,14 @@ class SLaM:
 
             return ag.GalaxyModel(
                 redshift=self.redshift_source,
-                bulge=results.last.instance.galaxies.source.bulge,
-                disk=results.last.instance.galaxies.source.disk,
-                envelope=results.last.instance.galaxies.source.envelope,
+                bulge=result.instance.galaxies.source.bulge,
+                disk=result.instance.galaxies.source.disk,
+                envelope=result.instance.galaxies.source.envelope,
                 hyper_galaxy=hyper_galaxy,
             )
 
-    def _source_inversion_from_results(
-        self, results: af.ResultsCollection, source_is_model: bool = False
+    def _source_inversion_from_result(
+        self, result: af.Result, source_is_model: bool = False
     ) -> ag.GalaxyModel:
         """
          Pass an inversion source `PriorModel` as a `model` or `instance` from a previous pipeline.
@@ -638,9 +656,7 @@ class SLaM:
         ag.GalaxyModel
             Contains the `PriorModel`'s of the source's pixelization, regularization, etc.
         """
-        hyper_galaxy = self.setup_hyper.hyper_galaxy_source_from_result(
-            result=results.last
-        )
+        hyper_galaxy = self.setup_hyper.hyper_galaxy_source_from_result(result=result)
 
         if not self.setup_hyper.hyper_fixed_after_source:
 
@@ -648,8 +664,8 @@ class SLaM:
 
                 return ag.GalaxyModel(
                     redshift=self.redshift_source,
-                    pixelization=results.last.hyper.instance.galaxies.source.pixelization,
-                    regularization=results.last.hyper.model.galaxies.source.regularization,
+                    pixelization=result.hyper.instance.galaxies.source.pixelization,
+                    regularization=result.hyper.model.galaxies.source.regularization,
                     hyper_galaxy=hyper_galaxy,
                 )
 
@@ -657,8 +673,8 @@ class SLaM:
 
                 return ag.GalaxyModel(
                     redshift=self.redshift_source,
-                    pixelization=results.last.hyper.instance.galaxies.source.pixelization,
-                    regularization=results.last.hyper.instance.galaxies.source.regularization,
+                    pixelization=result.hyper.instance.galaxies.source.pixelization,
+                    regularization=result.hyper.instance.galaxies.source.regularization,
                     hyper_galaxy=hyper_galaxy,
                 )
 
@@ -668,8 +684,8 @@ class SLaM:
 
                 return ag.GalaxyModel(
                     redshift=self.redshift_source,
-                    pixelization=results.last.instance.galaxies.source.pixelization,
-                    regularization=results.last.model.galaxies.source.regularization,
+                    pixelization=result.instance.galaxies.source.pixelization,
+                    regularization=result.model.galaxies.source.regularization,
                     hyper_galaxy=hyper_galaxy,
                 )
 
@@ -677,13 +693,13 @@ class SLaM:
 
                 return ag.GalaxyModel(
                     redshift=self.redshift_source,
-                    pixelization=results.last.instance.galaxies.source.pixelization,
-                    regularization=results.last.instance.galaxies.source.regularization,
+                    pixelization=result.instance.galaxies.source.pixelization,
+                    regularization=result.instance.galaxies.source.regularization,
                     hyper_galaxy=hyper_galaxy,
                 )
 
-    def source_from_results(
-        self, results: af.ResultsCollection, source_is_model: bool = False
+    def source_from_result(
+        self, result: af.Result, source_is_model: bool = False
     ) -> ag.GalaxyModel:
         """
         Setup the source model using the previous pipeline and phase results.
@@ -707,17 +723,15 @@ class SLaM:
 
         if self.pipeline_source_inversion is None:
 
-            return self._source_parametric_from_results(
-                results=results, source_is_model=source_is_model
+            return self._source_parametric_from_result(
+                result=result, source_is_model=source_is_model
             )
 
-        else:
+        return self._source_inversion_from_result(
+            result=result, source_is_model=source_is_model
+        )
 
-            return self._source_inversion_from_results(
-                results=results, source_is_model=source_is_model
-            )
-
-    def source_from_results_model_if_parametric(self, results: af.ResultsCollection):
+    def source_from_result_model_if_parametric(self, result: af.Result):
         """Setup the source model for a Mass pipeline using the previous pipeline and phase results.
 
         The source light model is not specified by the pipeline Mass pipeline (e.g. the previous pipelines are used to
@@ -734,10 +748,10 @@ class SLaM:
             The result of the previous source pipeline.  
         """
         if self.pipeline_source_inversion is None:
-            return self.source_from_results(results=results, source_is_model=True)
-        return self.source_from_results(results=results, source_is_model=False)
+            return self.source_from_result(result=result, source_is_model=True)
+        return self.source_from_result(result=result, source_is_model=False)
 
-    def source_for_subhalo_pipeline_from_results(self, results: af.ResultsCollection):
-        return self.source_from_results(
-            results=results, source_is_model=self.setup_subhalo.source_is_model
+    def source_for_subhalo_pipeline_from_result(self, result: af.Result):
+        return self.source_from_result(
+            result=result, source_is_model=self.setup_subhalo.source_is_model
         )
