@@ -34,7 +34,7 @@ def pixel_scale_from_instrument(instrument):
 
 def grid_from_instrument(instrument):
     """
-    Returns the `Grid` from an instrument type based on real observations.
+    Returns the `Grid2D` from an instrument type based on real observations.
 
     These options are representative of VRO, Euclid, HST, over-sampled HST and Adaptive Optics image.
 
@@ -44,15 +44,15 @@ def grid_from_instrument(instrument):
         A string giving the resolution of the desired instrument (VRO | Euclid | HST | HST_Up | AO).
     """
     if instrument in "vro":
-        return al.GridIterate.uniform(shape_2d=(80, 80), pixel_scales=0.2)
+        return al.Grid2DIterate.uniform(shape_native=(80, 80), pixel_scales=0.2)
     elif instrument in "euclid":
-        return al.GridIterate.uniform(shape_2d=(120, 120), pixel_scales=0.1)
+        return al.Grid2DIterate.uniform(shape_native=(120, 120), pixel_scales=0.1)
     elif instrument in "hst":
-        return al.GridIterate.uniform(shape_2d=(200, 200), pixel_scales=0.05)
+        return al.Grid2DIterate.uniform(shape_native=(200, 200), pixel_scales=0.05)
     elif instrument in "hst_up":
-        return al.GridIterate.uniform(shape_2d=(300, 300), pixel_scales=0.03)
+        return al.Grid2DIterate.uniform(shape_native=(300, 300), pixel_scales=0.03)
     elif instrument in "ao":
-        return al.GridIterate.uniform(shape_2d=(800, 800), pixel_scales=0.01)
+        return al.Grid2DIterate.uniform(shape_native=(800, 800), pixel_scales=0.01)
     else:
         raise ValueError("An invalid instrument was entered - ", instrument)
 
@@ -69,25 +69,25 @@ def psf_from_instrument(instrument):
         A string giving the resolution of the desired instrument (VRO | Euclid | HST | HST_Up | AO).
     """
     if instrument in "vro":
-        return al.Kernel.from_gaussian(
-            shape_2d=(31, 31), sigma=0.5, pixel_scales=0.2, renormalize=True
+        return al.Kernel2D.from_gaussian(
+            shape_native=(31, 31), sigma=0.5, pixel_scales=0.2, renormalize=True
         )
 
     elif instrument in "euclid":
-        return al.Kernel.from_gaussian(
-            shape_2d=(31, 31), sigma=0.1, pixel_scales=0.1, renormalize=True
+        return al.Kernel2D.from_gaussian(
+            shape_native=(31, 31), sigma=0.1, pixel_scales=0.1, renormalize=True
         )
     elif instrument in "hst":
-        return al.Kernel.from_gaussian(
-            shape_2d=(31, 31), sigma=0.05, pixel_scales=0.05, renormalize=True
+        return al.Kernel2D.from_gaussian(
+            shape_native=(31, 31), sigma=0.05, pixel_scales=0.05, renormalize=True
         )
     elif instrument in "hst_up":
-        return al.Kernel.from_gaussian(
-            shape_2d=(31, 31), sigma=0.05, pixel_scales=0.03, renormalize=True
+        return al.Kernel2D.from_gaussian(
+            shape_native=(31, 31), sigma=0.05, pixel_scales=0.03, renormalize=True
         )
     elif instrument in "ao":
-        return al.Kernel.from_gaussian(
-            shape_2d=(31, 31), sigma=0.025, pixel_scales=0.01, renormalize=True
+        return al.Kernel2D.from_gaussian(
+            shape_native=(31, 31), sigma=0.025, pixel_scales=0.01, renormalize=True
         )
 
     else:
@@ -176,30 +176,30 @@ def simulate_imaging_from_instrument(instrument, dataset_name, galaxies):
         overwrite=True,
     )
 
-    plotter = aplt.Plotter(output=aplt.Output(path=dataset_path, format="png"))
-    sub_plotter = aplt.SubPlotter(output=aplt.Output(path=dataset_path, format="png"))
+    plotter = aplt.MatPlot2D(output=aplt.Output(path=dataset_path, format="png"))
+    plotter = aplt.MatPlot2D(output=aplt.Output(path=dataset_path, format="png"))
 
-    aplt.Imaging.subplot_imaging(imaging=imaging, sub_plotter=sub_plotter)
+    aplt.Imaging.subplot_imaging(imaging=imaging, plotter=plotter)
 
-    aplt.Imaging.individual(
+    aplt.imaging.individual(
         imaging=imaging,
-        plot_image=True,
-        plot_noise_map=True,
-        plot_psf=True,
-        plot_signal_to_noise_map=True,
+        image=True,
+        noise_map=True,
+        psf=True,
+        signal_to_noise_map=True,
         plotter=plotter,
     )
 
-    aplt.Tracer.subplot_tracer(tracer=tracer, grid=grid, sub_plotter=sub_plotter)
+    aplt.Tracer.subplot_tracer(tracer=tracer, grid=grid, plotter=plotter)
 
-    aplt.Tracer.individual(
+    aplt.Tracer.figures(
         tracer=tracer,
         grid=grid,
-        plot_image=True,
-        plot_source_plane=True,
-        plot_convergence=True,
-        plot_potential=True,
-        plot_deflections=True,
+        image=True,
+        source_plane=True,
+        convergence=True,
+        potential=True,
+        deflections=True,
         plotter=plotter,
     )
 
