@@ -1,3 +1,4 @@
+from autoarray.structures import grids
 import autolens as al
 from autolens.lens import positions_solver as pos
 
@@ -11,9 +12,9 @@ class TestAbstractPositionsSolver:
         self,
     ):
 
-        grid = al.Grid.manual_1d(
+        grid = al.Grid2D.manual_slim(
             grid=[[0.0, -0.1], [0.0, 0.0], [0.0, 0.1]],
-            shape_2d=(1, 3),
+            shape_native=(1, 3),
             pixel_scales=0.1,
         )
 
@@ -77,22 +78,55 @@ class TestAbstractPositionsSolver:
 
         assert (grid == grid_util).all()
 
-
-class TestPositionFinder:
-    def test__positions_found_for_simple_mass_profiles(self):
-
-        grid = al.Grid.uniform(shape_2d=(100, 100), pixel_scales=0.05)
+    def test__grid_with_points_below_magnification_threshold_removed(self):
 
         sis = al.mp.SphericalIsothermal(centre=(0.0, 0.0), einstein_radius=1.0)
 
-        solver = al.PositionsFinder(grid=grid, pixel_scale_precision=0.01)
+        grid = grids.Grid2DIrregularUniform(
+            grid=[(1.0, 0.0), (0.1, 0.0)], pixel_scales=0.01
+        )
+
+        magnification = np.abs(
+            sis.magnification_via_hessian_from_grid(grid=grid, buffer=grid.pixel_scale)
+        )
+
+        assert magnification[0] > 1000.0
+        assert magnification[1] < 1000.0
+
+        solver = pos.AbstractPositionsSolver(magnification_threshold=1000.0)
+
+        positions = solver.grid_with_points_below_magnification_threshold_removed(
+            lensing_obj=sis, grid=grid
+        )
+
+        assert positions.in_list == [(1.0, 0.0)]
+        assert positions.pixel_scales == (0.01, 0.01)
+
+        solver = pos.AbstractPositionsSolver(magnification_threshold=0.0)
+
+        positions = solver.grid_with_points_below_magnification_threshold_removed(
+            lensing_obj=sis, grid=grid
+        )
+
+        assert positions.in_list == [(1.0, 0.0), (0.1, 0.0)]
+        assert positions.pixel_scales == (0.01, 0.01)
+
+
+class TestPositionSolver:
+    def test__positions_found_for_simple_mass_profiles(self):
+
+        grid = al.Grid2D.uniform(shape_native=(100, 100), pixel_scales=0.05)
+
+        sis = al.mp.SphericalIsothermal(centre=(0.0, 0.0), einstein_radius=1.0)
+
+        solver = al.PositionsSolver(grid=grid, pixel_scale_precision=0.01)
 
         positions = solver.solve(lensing_obj=sis, source_plane_coordinate=(0.0, 0.11))
 
-        assert positions[0] == pytest.approx(np.array([0.003125, -0.89062]), 1.0e-4)
-        assert positions[1] == pytest.approx(np.array([-0.003125, -0.89062]), 1.0e-4)
+        assert positions[0] == pytest.approx(np.array([0.003125, -0.890625]), 1.0e-4)
+        assert positions[3] == pytest.approx(np.array([-0.003125, 1.109375]), 1.0e-4)
 
-        grid = al.Grid.uniform(shape_2d=(100, 100), pixel_scales=0.05, sub_size=1)
+        grid = al.Grid2D.uniform(shape_native=(100, 100), pixel_scales=0.05, sub_size=1)
 
         g0 = al.Galaxy(
             redshift=0.5,
@@ -107,111 +141,16 @@ class TestPositionFinder:
 
         tracer = al.Tracer.from_galaxies(galaxies=[g0, g1])
 
-        solver = pos.PositionsFinder(grid=grid, pixel_scale_precision=0.01)
+        solver = pos.PositionsSolver(grid=grid, pixel_scale_precision=0.01)
 
         coordinates = solver.solve(
             lensing_obj=tracer, source_plane_coordinate=(0.0, 0.0)
         )
 
-        assert coordinates.in_grouped_list[0][0] == pytest.approx(
-            (1.028125, -0.003125), 1.0e-4
-        )
-        assert coordinates.in_grouped_list[0][1] == pytest.approx(
-            (0.009375, -0.95312), 1.0e-4
-        )
-        assert coordinates.in_grouped_list[0][2] == pytest.approx(
-            (0.009375, 0.95312), 1.0e-4
-        )
-        assert coordinates.in_grouped_list[0][3] == pytest.approx(
-            (-1.028125, -0.003125), 1.0e-4
-        )
-
-    def test__same_as_above_using_solver_for_tracer_method(self):
-
-        grid = al.Grid.uniform(shape_2d=(100, 100), pixel_scales=0.05, sub_size=1)
-
-        g0 = al.Galaxy(
-            redshift=0.5,
-            mass=al.mp.EllipticalIsothermal(
-                centre=(0.001, 0.001),
-                einstein_radius=1.0,
-                elliptical_comps=(0.0, 0.111111),
-            ),
-        )
-
-        g1 = al.Galaxy(
-            redshift=1.0, light=al.lp.EllipticalLightProfile(centre=(0.0, 0.0))
-        )
-
-        tracer = al.Tracer.from_galaxies(galaxies=[g0, g1])
-
-        solver = pos.PositionsFinder(grid=grid, pixel_scale_precision=0.01)
-
-        coordinates = solver.solve_from_tracer(tracer=tracer)
-
-        assert coordinates.in_grouped_list[0][0] == pytest.approx(
-            (1.028125, -0.003125), 1.0e-4
-        )
-        assert coordinates.in_grouped_list[0][1] == pytest.approx(
-            (0.009375, -0.95312), 1.0e-4
-        )
-        assert coordinates.in_grouped_list[0][2] == pytest.approx(
-            (0.009375, 0.95312), 1.0e-4
-        )
-        assert coordinates.in_grouped_list[0][3] == pytest.approx(
-            (-1.028125, -0.003125), 1.0e-4
-        )
-
-    def test__solver_for_tracer_method__multiple_source_planes_or_galaxies(self):
-
-        grid = al.Grid.uniform(shape_2d=(50, 50), pixel_scales=0.05, sub_size=4)
-
-        g0 = al.Galaxy(
-            redshift=0.5,
-            mass=al.mp.EllipticalIsothermal(
-                centre=(0.0, 0.0), einstein_radius=1.0, elliptical_comps=(0.0, 0.055555)
-            ),
-        )
-
-        g1 = al.Galaxy(
-            redshift=1.0,
-            light_0=al.lp.EllipticalLightProfile(centre=(0.0, 0.0)),
-            light_1=al.lp.EllipticalLightProfile(centre=(0.1, 0.1)),
-        )
-
-        tracer = al.Tracer.from_galaxies(galaxies=[g0, g1])
-
-        solver = pos.PositionsFinder(grid=grid, pixel_scale_precision=0.01)
-
-        position_manual_0 = solver.solve(
-            lensing_obj=tracer, source_plane_coordinate=(0.0, 0.0)
-        )
-
-        position_manual_1 = solver.solve(
-            lensing_obj=tracer, source_plane_coordinate=(0.1, 0.1)
-        )
-
-        positions = solver.solve_from_tracer(tracer=tracer)
-
-        assert position_manual_0.in_grouped_list[0] == positions.in_grouped_list[0]
-        assert position_manual_1.in_grouped_list[0] == positions.in_grouped_list[1]
-
-        g2 = al.Galaxy(
-            redshift=1.0, light=al.lp.EllipticalLightProfile(centre=(0.0, 0.0))
-        )
-
-        g3 = al.Galaxy(
-            redshift=1.0, light=al.lp.EllipticalLightProfile(centre=(0.1, 0.1))
-        )
-
-        tracer = al.Tracer.from_galaxies(galaxies=[g0, g2, g3])
-
-        solver = pos.PositionsFinder(grid=grid, pixel_scale_precision=0.01)
-
-        positions = solver.solve_from_tracer(tracer=tracer)
-
-        assert position_manual_0.in_grouped_list[0] == positions.in_grouped_list[0]
-        assert position_manual_1.in_grouped_list[0] == positions.in_grouped_list[1]
+        assert coordinates.in_list[0] == pytest.approx((1.028125, -0.003125), 1.0e-4)
+        assert coordinates.in_list[1] == pytest.approx((0.009375, -0.95312), 1.0e-4)
+        assert coordinates.in_list[2] == pytest.approx((0.009375, 0.95312), 1.0e-4)
+        assert coordinates.in_list[3] == pytest.approx((-1.028125, -0.003125), 1.0e-4)
 
 
 class TestGridRemoveDuplicates:
@@ -589,7 +528,7 @@ class TestGridBuffedAroundCoordinate:
 class TestGridNeighbors1d:
     def test__creates_numpy_array_with_correct_neighbors(self):
 
-        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_1d=9)
+        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_slim=9)
 
         assert (
             neighbors_1d
@@ -613,7 +552,7 @@ class TestGridNeighbors1d:
             == np.array([False, False, False, False, True, False, False, False, False])
         ).all()
 
-        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_1d=16)
+        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_slim=16)
 
         assert (
             neighbors_1d
@@ -667,7 +606,7 @@ class TestGridNeighbors1d:
 class TestPairCoordinateToGrid:
     def test__coordinate_paired_to_closest_pixel_on_grid(self):
 
-        grid_1d = np.array(
+        grid_slim = np.array(
             [
                 [1.0, -1.0],
                 [1.0, 0.0],
@@ -682,25 +621,25 @@ class TestPairCoordinateToGrid:
         )
 
         index = pos.pair_coordinate_to_closest_pixel_on_grid(
-            coordinate=(1.0, -1.0), grid_1d=grid_1d
+            coordinate=(1.0, -1.0), grid_slim=grid_slim
         )
 
         assert index == 0
 
         index = pos.pair_coordinate_to_closest_pixel_on_grid(
-            coordinate=(1.0, 1.0), grid_1d=grid_1d
+            coordinate=(1.0, 1.0), grid_slim=grid_slim
         )
 
         assert index == 2
 
         index = pos.pair_coordinate_to_closest_pixel_on_grid(
-            coordinate=(1.01, 1.10), grid_1d=grid_1d
+            coordinate=(1.01, 1.10), grid_slim=grid_slim
         )
 
         assert index == 2
 
         index = pos.pair_coordinate_to_closest_pixel_on_grid(
-            coordinate=(10.0, 10.0), grid_1d=grid_1d
+            coordinate=(10.0, 10.0), grid_slim=grid_slim
         )
 
         assert index == 2
@@ -711,7 +650,7 @@ class TestGridPeaks:
 
         distance_1d = np.array([1.0, 1.0, 1.0, 1.0, 0.0, 1.0, 1.0, 1.0, 1.0])
 
-        grid_1d = np.array(
+        grid_slim = np.array(
             [
                 [1.0, -1.0],
                 [1.0, 0.0],
@@ -725,11 +664,11 @@ class TestGridPeaks:
             ]
         )
 
-        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_1d=9)
+        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_slim=9)
 
         peaks_coordinates = pos.grid_peaks_from(
             distance_1d=distance_1d,
-            grid_1d=grid_1d,
+            grid_slim=grid_slim,
             neighbors=neighbors_1d.astype("int"),
             has_neighbors=has_neighbors,
         )
@@ -766,13 +705,13 @@ class TestGridPeaks:
             ]
         )
 
-        grid_1d = al.Grid.uniform(shape_2d=(5, 5), pixel_scales=1.0)
+        grid_slim = al.Grid2D.uniform(shape_native=(5, 5), pixel_scales=1.0)
 
-        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_1d=25)
+        neighbors_1d, has_neighbors = pos.grid_square_neighbors_1d_from(shape_slim=25)
 
         peaks_coordinates = pos.grid_peaks_from(
             distance_1d=distance_1d,
-            grid_1d=grid_1d,
+            grid_slim=grid_slim,
             neighbors=neighbors_1d.astype("int"),
             has_neighbors=has_neighbors,
         )
@@ -785,24 +724,24 @@ class TestGridPeaks:
 class TestWithinDistance:
     def test__grid_keeps_only_points_within_distance(self):
 
-        grid_1d = np.array([[2.0, 2.0], [1.0, 1.0], [3.0, 3.0]])
+        grid_slim = np.array([[2.0, 2.0], [1.0, 1.0], [3.0, 3.0]])
 
         distances_1d = np.array([2.0, 1.0, 3.0])
 
         new_grid = pos.grid_within_distance(
-            distances_1d=distances_1d, grid_1d=grid_1d, within_distance=10.0
+            distances_1d=distances_1d, grid_slim=grid_slim, within_distance=10.0
         )
 
-        assert (new_grid == grid_1d).all()
+        assert (new_grid == grid_slim).all()
 
         new_grid = pos.grid_within_distance(
-            distances_1d=distances_1d, grid_1d=grid_1d, within_distance=2.5
+            distances_1d=distances_1d, grid_slim=grid_slim, within_distance=2.5
         )
 
         assert (new_grid == np.array([[2.0, 2.0], [1.0, 1.0]])).all()
 
         new_grid = pos.grid_within_distance(
-            distances_1d=distances_1d, grid_1d=grid_1d, within_distance=1.5
+            distances_1d=distances_1d, grid_slim=grid_slim, within_distance=1.5
         )
 
         assert (new_grid == np.array([[1.0, 1.0]])).all()
