@@ -1,6 +1,10 @@
 import autofit as af
 import autolens as al
 
+from autolens.mock import mock
+
+import pytest
+
 
 class TestSetupHyper:
     def test__hyper_galaxies_names_and_tag_for_lens_and_source(self):
@@ -82,6 +86,47 @@ class TestSetupSource:
         assert setup.tag == "source[parametric__bulge_sersic]"
 
 
+class TestSetupMassLightDark:
+    def test__update_stellar_mass_priors_using_einstein_radius(self):
+
+        grid = al.Grid2D.uniform(shape_native=(200, 200), pixel_scales=0.05)
+
+        tracer = mock.MockTracer(einstein_radius=1.0, einstein_mass=4.0)
+        fit = mock.MockFit(grid=grid)
+
+        result = mock.MockResult(
+            max_log_likelihood_tracer=tracer, max_log_likelihood_fit=fit
+        )
+
+        bulge_prior_model = af.PriorModel(al.lmp.SphericalSersic)
+
+        bulge_prior_model.intensity = af.UniformPrior(
+            lower_limit=0.99, upper_limit=1.01
+        )
+        bulge_prior_model.effective_radius = af.UniformPrior(
+            lower_limit=0.99, upper_limit=1.01
+        )
+        bulge_prior_model.sersic_index = af.UniformPrior(
+            lower_limit=2.99, upper_limit=3.01
+        )
+
+        setup = al.SetupMassLightDark(bulge_prior_model=bulge_prior_model)
+
+        setup.update_stellar_mass_priors_from_result(
+            prior_model=bulge_prior_model,
+            result=result,
+            einstein_mass_range=[0.001, 10.0],
+            bins=10,
+        )
+
+        assert setup.bulge_prior_model.mass_to_light_ratio.lower_limit == pytest.approx(
+            0.00040519, 1.0e-1
+        )
+        assert setup.bulge_prior_model.mass_to_light_ratio.upper_limit == pytest.approx(
+            4.051935, 1.0e-1
+        )
+
+
 class TestSetupSubhalo:
     def test__subhalo_prior_model_and_tags(self):
 
@@ -187,7 +232,7 @@ class TestSetupPipeline:
         assert (
             setup.tag == "setup__"
             "hyper[galaxies_lens__bg_sky__bg_noise]__"
-            "mass[light_dark__bulge_sersic__disk_exp__mlr_free__dark_nfw_sph_ludlow__with_shear__align_bulge_dark_centre]"
+            "mass[light_dark__bulge_sersic__disk_exp__mlr_free__dark_nfw_ludlow__with_shear__align_bulge_dark_centre]"
         )
 
         setup_source = al.SetupSourceInversion(
@@ -206,7 +251,7 @@ class TestSetupPipeline:
         assert (
             setup.tag == "setup__"
             "light[parametric__bulge_sersic__disk_exp__align_bulge_disk_centre__centre_(1.00,2.00)]__"
-            "mass[light_dark__bulge_sersic__disk_exp__mlr_free__dark_nfw_sph_ludlow__no_shear__centre_(3.00,4.00)]__"
+            "mass[light_dark__bulge_sersic__disk_exp__mlr_free__dark_nfw_ludlow__no_shear__centre_(3.00,4.00)]__"
             "source[inversion__pix_rect__reg_const]"
         )
 
@@ -216,7 +261,7 @@ class TestSetupPipeline:
 
         assert (
             setup.tag == "setup__"
-            "mass[light_dark__bulge_sersic__disk_exp__mlr_free__dark_nfw_sph_ludlow__with_shear__align_bulge_dark_centre]"
+            "mass[light_dark__bulge_sersic__disk_exp__mlr_free__dark_nfw_ludlow__with_shear__align_bulge_dark_centre]"
         )
 
         smbh = al.SetupSMBH(smbh_centre_fixed=True)
